unofficial mirror of meta@public-inbox.org
 help / color / mirror / Atom feed
From: Eric Wong <e@80x24.org>
To: meta@public-inbox.org
Subject: [PATCH] searchview: s/threaded/nested/
Date: Wed, 29 Nov 2017 09:27:33 +0000	[thread overview]
Message-ID: <20171129092733.GA6540@dcvr> (raw)
In-Reply-To: <20171019071803.14159-1-e@80x24.org>

We want to be consistent with the view change in
commit b223e6f49debb99b9132bc85d97a065ebcee00b9
---
 lib/PublicInbox/SearchView.pm | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/lib/PublicInbox/SearchView.pm b/lib/PublicInbox/SearchView.pm
index c42cf2d..39400d6 100644
--- a/lib/PublicInbox/SearchView.pm
+++ b/lib/PublicInbox/SearchView.pm
@@ -79,7 +79,7 @@ sub load_doc_retry {
 	}
 }
 
 # display non-threaded search results similar to what users expect from
 # regular WWW search engines:
 sub mset_summary {
 	my ($ctx, $mset, $q) = @_;
@@ -157,10 +157,10 @@ sub search_nav_top {
 	my $x = $q->{x};
 	if ($x eq '') {
 		my $t = $q->qs_html(x => 't');
-		$rv .= qq{<b>summary</b>|<a\nhref="?$t">threaded</a>}
+		$rv .= qq{<b>summary</b>|<a\nhref="?$t">nested</a>}
 	} elsif ($q->{x} eq 't') {
 		my $s = $q->qs_html(x => '');
-		$rv .= qq{<a\nhref="?$s">summary</a>|<b>threaded</b>};
+		$rv .= qq{<a\nhref="?$s">summary</a>|<b>nested</b>};
 	}
 	my $A = $q->qs_html(x => 'A', r => undef);
 	$rv .= qq{|<a\nhref="?$A">Atom feed</a>]};
@@ -79,7 +79,7 @@ sub load_doc_retry {
 }
 
-# display non-threaded search results similar to what users expect from
+# display non-nested search results similar to what users expect from
 # regular WWW search engines:
 sub mset_summary {
-- 
EW

      reply	other threads:[~2017-11-29  9:27 UTC|newest]

Thread overview: 2+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2017-10-19  7:18 [PATCH] view: s/threaded/nested/ in view Eric Wong
2017-11-29  9:27 ` Eric Wong [this message]

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

  List information: https://public-inbox.org/README

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20171129092733.GA6540@dcvr \
    --to=e@80x24.org \
    --cc=meta@public-inbox.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).